module.exports = defineTest({
	description: 'renames named and default imports'
});

// test copied from https://github.com/esnext/es6-module-transpiler/tree/master/test/examples/import-as
